@@ -563,7 +563,7 @@ class Connection:
                 # deep-copy the Retry object as it is mutable
                 self.retry = copy.deepcopy(retry)
             # Update the retry's supported errors with the specified errors
-            self.retry.update_supported_erros(retry_on_error)
+            self.retry.update_supported_errors(retry_on_error)
         else:
             self.retry = Retry(NoBackoff(), 0)
         self.health_check_interval = health_check_interval
@@ -808,7 +808,13 @@ class Connection:
         sock = self._sock
         if not sock:
             self.connect()
-        return self._parser.can_read(timeout)
+        try:
+            return self._parser.can_read(timeout)
+        except OSError as e:
+            self.disconnect()
+            raise ConnectionError(
+                f"Error while reading from {self.host}:{self.port}: {e.args}"
+            )
 
     def read_response(self, disable_decoding=False):
         """Read the response from a previously sent command"""
@@ -1099,7 +1105,7 @@ class UnixDomainSocketConnection(Connection):
                 # deep-copy the Retry object as it is mutable
                 self.retry = copy.deepcopy(retry)
             # Update the retry's supported errors with the specified errors
-            self.retry.update_supported_erros(retry_on_error)
+            self.retry.update_supported_errors(retry_on_error)
         else:
             self.retry = Retry(NoBackoff(), 0)
         self.health_check_interval = health_check_interval
